==> seedsui-react-5.6.60.tgz: package/lib/InputLocation/Browser/BMap.js <==
import React, { useEffect, useRef } from 'react';
import MapUtil from "./../../MapUtil";
import Notice from "./../../Notice";
import locale from "./../../locale";
import helper from "./helper";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BMap = function BMap(_ref) {
  var errMsg = _ref.errMsg,
    changeState = _ref.changeState,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    defaultChecked = _ref.defaultChecked,
    onMapClose = _ref.onMapClose,
    callback = _ref.callback;
  var refWrapperEl = useRef(null);
  useEffect(function () {
    MapUtil.load({
      ak: '3pTjiH1BXLjASHeBmWUuSF83',
      success: function success() {
        initData();
      },
      fail: function fail() {
        changeState && changeState({
          errMsg: locale('地图库加载失败，请稍后再试！', 'ZKGJ031269')
        });
      }
    });
  }, []); // eslint-disable-line

  var onMapLocation = function onMapLocation() {
    helper.location(callback);
  };
  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      changeState({
        errMsg: locale('地图库加载失败，请稍后再试！', 'ZKGJ031269')
      });
      return;
    }
    if (!refWrapperEl.current) {
      changeState({
        errMsg: locale('地图容器不存在', 'ZKGJ029837')
      });
      return;
    }
    helper.initMap(refWrapperEl.current, {
      defaultChecked: defaultChecked,
      onMapClose: onMapClose,
      onMapLocation: onMapLocation,
      list: list
    }, callback);
  }
  useEffect(function () {
    if (helper.init && list) {
      helper.drawMap(list);
    }
  }, [list]); // eslint-disable-line

  return /*#__PURE__*/_jsxs("div", {
    children: [/*#__PURE__*/_jsx("div", {
      className: "map-container",
      ref: refWrapperEl
    }), errMsg && /*#__PURE__*/_jsx(Notice, {
      caption: errMsg
    })]
  });
};
function areEqual(prevProps, nextProps) {
  return JSON.stringify(prevProps) === JSON.stringify(nextProps);
}
export default /*#__PURE__*/React.memo(BMap, areEqual);

==> seedsui-react-5.8.44.tgz: package/lib/InputLocation/Browser/BMap.js <==
import React, { useEffect, useRef } from 'react';
import MapUtil from "./../../MapUtil";
import Notice from "./../../Notice";
import locale from "./../../locale";
import helper from "./helper";
var BMap = function BMap(_ref) {
  var errMsg = _ref.errMsg,
    changeState = _ref.changeState,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    defaultChecked = _ref.defaultChecked,
    onMapClose = _ref.onMapClose,
    callback = _ref.callback;
  var refWrapperEl = useRef(null);
  useEffect(function () {
    MapUtil.load({
      ak: '3pTjiH1BXLjASHeBmWUuSF83',
      success: function success() {
        initData();
      },
      fail: function fail() {
        changeState && changeState({
          errMsg: locale('地图库加载失败，请稍后再试！', 'SeedsUI_map_js_load_failed')
        });
      }
    });
  }, []); // eslint-disable-line

  var onMapLocation = function onMapLocation() {
    helper.location(callback);
  };
  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      changeState({
        errMsg: locale('地图库加载失败，请稍后再试！', 'SeedsUI_map_js_load_failed')
      });
      return;
    }
    if (!refWrapperEl.current) {
      changeState({
        errMsg: locale('地图容器不存在', 'SeedsUI_no_mapcontainer_error')
      });
      return;
    }
    helper.initMap(refWrapperEl.current, {
      defaultChecked: defaultChecked,
      onMapClose: onMapClose,
      onMapLocation: onMapLocation,
      list: list
    }, callback);
  }
  useEffect(function () {
    if (helper.init && list) {
      helper.drawMap(list);
    }
  }, [list]); // eslint-disable-line

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "map-container",
    ref: refWrapperEl
  }), errMsg && /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));
};
function areEqual(prevProps, nextProps) {
  return JSON.stringify(prevProps) === JSON.stringify(nextProps);
}
export default /*#__PURE__*/React.memo(BMap, areEqual);
